@@ -24,7 +24,10 @@ class Config:
         config.view_sample = str(data['view_sample'])
         config.delint_mode = bool(data['delint_mode'])
         config.show_ab_channels = bool(data['show_ab_channels'])
-        config.log_ratio_rnge = (data['log_ratio_rnge'])
+        if (data['log_ratio_rnge']) is None:
+            config.log_ratio_rnge = (data['log_ratio_rnge'])
+        else:
+            config.log_ratio_rnge = tuple(data['log_ratio_rnge'])
         config.hexbins = bool(data['hexbins'])
         config.hexbin_grid_size = int(data['hexbin_grid_size'])
         config.channel_exclusions = list(data['channel_exclusions'])
@@ -40,10 +43,11 @@ class Config:
         config.learningRate = float(data['learningRate'])
         config.metric = str(data['metric'])
         config.random_state = int(data['random_state'])
+        config.numThumbnails = int(data['numThumbnails'])
+        config.squareWindowDimension = int(data['squareWindowDimension'])
         config.denominator_cluster = int(data['denominator_cluster'])
         config.FDRCorrection = bool(data['FDRCorrection'])
         config.bonferroniCorrection = bool(data['bonferroniCorrection'])
-        config.numThumbnails = int(data['numThumbnails'])
         config.cropDict = dict(data['cropDict'])
         config.spatialDict1 = dict(data['spatialDict1'])
         config.spatialDict2 = dict(data['spatialDict2'])
